/'--------------------------------------------------------------------
                      Asteroids (c) ATARI INC              
                  Remake by Vincent DeCampo 2009      

   This program is free software: you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public License
as published by the Free Software Foundation, either version 3 of
the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

--------------------------------------------------------------------'/

#Include "vbcompat.bi"
#Include "sound.bas"
#Include "Polylib.bas"
#Include "particle.bas"
#Include "vectfont.bas"

Const As Double GameTick = 1/30
Const As Double SpinTick = PI/360
Const As Double ShotTick = 1/60

'Screen Resolution
#Define SCR_W     800
#Define SCR_H     600

'Game Resolution
#Define DSP_W     800    
#Define DSP_H     600
#Define DSP_W2    DSP_W\2
#Define DSP_H2    DSP_H\2

#Define MAX_ROIDS 30
#Define MAX_SHOTS 4
#Define EXTRA_LIFE   10000

#Macro ReadVertices(rpoint,poly)
   Scope
      Dim As Integer vx,vy
      Restore rpoint
      Do
         Read vx,vy
         If vx=255 Then Exit Do
         poly.AddVertex(vx,vy)
      Loop
      poly.CenterVertices()
   End Scope
#EndMacro

Type _asteroid
   poly     As _polygon 
   size     As Double = 0
   heading  As Double
   speed    As Double
End Type

Type _player
   poly     As _polygon 'Ptr
   frame    As Integer
   heading  As Double
   yacc     As Double
   xacc     As Double
   respawn  As Double   'Respawn Timer
   lives    As Integer
   level    As Integer = 1
   astcount As Integer
   score    As Integer
   alive    As Integer = 1
   thrust   As Integer  'flag
   hyper    As Integer  'flag
   NextLife As Integer = EXTRA_LIFE
End Type

Type _shot
   poly     As _polygon 
   heading  As Double
   speed    As Double  
   ttl      As Double   'Time to Live
End Type

Type _saucer
   poly     As _polygon 
   size     As Integer
   heading  As Double
   speed    As Double
   alive    As Integer
   evasive  As Double
   newhead  As Double
   sound    As Integer
End Type

Type _HSCR Field = 1
	Player(2) As UByte => {65,65,65}
	Score		 As Integer
	Level		 As Integer
End Type

Declare Function SpawnShot(Player As _player Ptr, Shot As _shot Ptr) As Integer
Declare Function AllAsteroidsDestroyed( Asteroids As _asteroid Ptr) As Integer

Function GenerateAsteroids( roids As _asteroid Ptr, lvl As Integer) As Integer
Dim dummy As _asteroid
Dim NumRoids As Integer = (4+lvl)
   
   If NumRoids > MAX_ROIDS Then NumRoids = MAX_ROIDS
   
   For i As Integer = 0 To MAX_ROIDS-1
      roids[i] = dummy
   Next
   
   For i As Integer = 0 To NumRoids-1
      With roids[i]
         ReadVertices(Ast1,.poly)
         .size = 1+(Rnd*3)
         .heading = Rnd*PI*2
         .speed = 1+(Rnd*lvl)
         If .speed > 7 Then .speed = 7
         .poly.zoom = .size*5
         .poly.x = Cos(.heading)*DSP_W\2 + DSP_W\2
         .poly.y = Sin(.heading)*DSP_H\2 + DSP_H\2
      End With
   Next
   
   Return NumRoids
   
End Function

Function ProcessRoids( roids As _asteroid Ptr) As Integer
Dim As Double dx,dy
Dim As Integer astcount
   
   For i As Integer = 0 To MAX_ROIDS-1

      With roids[i]
         If .size Then
            astcount+=1
            'Process movement         
            dx = Cos(.heading)*.speed
            dy = Sin(.heading)*.speed
            .poly.x += dx
            .poly.y += dy
            If .poly.x < 0 Then .poly.x = DSP_W
            If .poly.y < 0 Then .poly.y = DSP_H
            If .poly.x > DSP_W Then .poly.x = 0
            If .poly.y > DSP_H Then .poly.y = 0
            'Process rotation
            .poly.rot += SpinTick*.speed
            If .poly.rot > PI Then .poly.rot = -PI
            If .poly.rot < -PI Then .poly.rot = PI
         End If
      End With
      
   Next
   
   Return astcount
   
End Function

Function ProcessPlayer( Player As _player Ptr, Shot As _shot Ptr) As Integer
Dim As Double dx,dy
Dim As Integer newshot

   Player->thrust = 0

   If Player->alive Then

      'Rotate Ship Left-Right
      If MultiKey(FB.SC_LEFT)  Then player->poly.rot -= .1
      If MultiKey(FB.SC_RIGHT) Then player->poly.rot += .1

      'Spacebar fires
      If MultiKey(FB.SC_SPACE) Then 
         newshot = SpawnShot(Player, Shot)
      End If
   
      'UP thrusts forward
      If MultiKey(FB.SC_UP) Then 
         If ( Abs(player->xacc)+Abs(player->yacc) )/2 < 6 Then
            player->heading = player->poly.rot
            dx = Cos(player->heading)
            dy = Sin(player->heading)
            player->xacc  += dx
            player->yacc  += dy
            Player->thrust = 1
         End If
      End If
      
      'CTRL to Hyperspace      
      If MultiKey(FB.SC_CONTROL) Then
         If Player->hyper = 0 Then
            Player->hyper = 1
            player->poly.x = Rnd*DSP_W
            player->poly.y = Rnd*DSP_H
         EndIf
      Else
         Player->hyper = 0
      EndIf
      
   End If
   
   With *Player

      'Process movement        
      .poly.x += .xacc
      .poly.y += .yacc
      
      If .poly.x < 0 Then .poly.x = DSP_W
      If .poly.y < 0 Then .poly.y = DSP_H
      If .poly.x > DSP_W Then .poly.x = 0
      If .poly.y > DSP_H Then .poly.y = 0

      'Process rotation
      If .poly.rot > PI  Then .poly.rot = -PI
      If .poly.rot < -PI Then .poly.rot = PI

   End With
   
   player->xacc *= .95
   player->yacc *= .95

   If Abs(player->xacc) < .1 Then player->xacc = 0
   If Abs(player->yacc) < .1 Then player->yacc = 0
  
   Return newshot
   
End Function

Sub SyncThrusterPositions(Player As _player Ptr, Thruster As _polygon Ptr)
   
   With *Player
      Thruster[0].x    = Player->poly.x
      Thruster[0].y    = Player->poly.y
      Thruster[0].rot  = Player->poly.rot
      Thruster[0].zoom = Player->poly.zoom
      Thruster[1].x    = Player->poly.x
      Thruster[1].y    = Player->poly.y
      Thruster[1].rot  = Player->poly.rot
      Thruster[1].zoom = Player->poly.zoom
   End With
   
End Sub

Function SpawnShot(Player As _player Ptr, Shot As _shot Ptr) As Integer
Static Reshoot As Double

   If Timer-Reshoot > .15 Then 'sec between shots

      For a As Integer = 0 To MAX_SHOTS-1
         If Shot[a].ttl  < Timer Then
            Shot[a].poly.x    = Player->poly.x
            Shot[a].poly.y    = Player->poly.y
            Shot[a].poly.rot  = Player->poly.rot
            Shot[a].poly.zoom = Player->poly.zoom
            Shot[a].heading   = Player->poly.rot
            Shot[a].speed     = 4.5
            Shot[a].ttl       = Timer+2
            Reshoot = Timer
            Return 1
         End If
      Next        
   
   End If
   
   Return 0
   
End Function

Function SpawnSaucerShot(Saucer As _saucer Ptr, Shot As _shot Ptr, Player As _player Ptr) As Integer

   With Shot[0]
      If .ttl  < Timer Then
         .poly.x    = Saucer->poly.x
         .poly.y    = Saucer->poly.y
         .poly.rot  = Saucer->poly.rot
         .poly.zoom = Saucer->poly.zoom
         .heading   = Atan2(Player->poly.y - Saucer->poly.y, Player->poly.x - Saucer->poly.x)
         If Saucer->size = 4 Then
            .heading = Rnd*PI2 'Large UFO shoots randomly
         End If
         .speed     = 4.5
         .ttl       = Timer+2
         Return 1
      End If
   End With
   
   Return 0
   
End Function

Sub ProcessShots(Shot As _shot Ptr)
Dim As Double dx,dy
   
   For i As Integer = 0 To MAX_SHOTS-1

      With Shot[i]
         If .ttl > Timer Then
            'Process movement         
            dx = Cos(.heading)*.speed
            dy = Sin(.heading)*.speed
            .poly.x += dx
            .poly.y += dy
            If .poly.x < 0 Then .poly.x = DSP_W
            If .poly.y < 0 Then .poly.y = DSP_H
            If .poly.x > DSP_W Then .poly.x = 0
            If .poly.y > DSP_H Then .poly.y = 0
         End If
      End With
      
   Next
     
End Sub

Sub ProcessSaucerShots(Shot As _shot Ptr)
Dim As Double dx,dy
   
   With Shot[0]
      If .ttl > Timer Then
         'Process movement         
         dx = Cos(.heading)*.speed
         dy = Sin(.heading)*.speed
         .poly.x += dx
         .poly.y += dy
         If .poly.x < 0 Then .poly.x = DSP_W
         If .poly.y < 0 Then .poly.y = DSP_H
         If .poly.x > DSP_W Then .poly.x = 0
         If .poly.y > DSP_H Then .poly.y = 0
      End If
   End With
     
End Sub

Sub SpawnNewAsteroid( Asteroids As _asteroid Ptr, index As Integer )

   For i As Integer = 0 To MAX_ROIDS-1
      With Asteroids[i]
         If .size = 0 Then
            Asteroids[i] = Asteroids[index]
            .heading = Rnd*PI*2
            .speed = Rnd*.speed+2
            .poly.zoom = .size*5
            Exit Sub         
         End If
      End With
   Next
   
End Sub

Function ProcessCollisionWithAsteroid( Asteroids As _asteroid Ptr, index As Integer ) As Integer

   With Asteroids[index]
      .size /= 2
      If .size < .5 Then
         .size = 0
      Else
         .heading = Rnd*PI*2
         .speed = Rnd*.speed+1
         .poly.zoom = .size*5         
         SpawnNewAsteroid( Asteroids , index )
      End If
   End With
   
   Return AllAsteroidsDestroyed(Asteroids)
   
End Function

Sub ProcessShipCollision( Player As _player Ptr)
   
   With *Player
      .alive   = 0
      .lives  -= 1
      .respawn = Timer+3
   End With
   
End Sub

Sub ProcessSaucer(Saucer As _saucer Ptr, Player As _player Ptr, SaucerShot As _shot Ptr, astcount As Integer)
Dim As Double dx,dy,newhead
   
   If Saucer->alive Then
      
      With Saucer[0]
         
         'Process movement 
         newhead = .heading        
         If .evasive > Timer Then
            newhead = .heading + .newhead
         Else
            If Rnd*200 < 1 Then
               .newhead = Rnd*PI/2 - PI/4
               .evasive = Timer + 2
            End If
         End If
         
         dx = Cos(newhead)*.speed
         dy = Sin(newhead)*.speed
         .poly.x += dx
         .poly.y += dy
         
         If .poly.x < 0 Then .alive = 0
         If .poly.y < 0 Then .poly.y = DSP_H
         If .poly.x > DSP_W Then .alive = 0
         If .poly.y > DSP_H Then .poly.y = 0
         
         SpawnSaucerShot(Saucer, SaucerShot, Player)
         
      End With
      
   Else
      
      If astcount < (Player->level+3) Then 'spawn when asteroid count is low
         'Check to see if we should spawn UFO
         If RND1000 < Player->level Then
            If RNDBOOL Then
               Saucer->heading = 0
               Saucer->poly.x = 0
            Else
               Saucer->heading = PI
               Saucer->poly.x = DSP_W
            End If
            Saucer->alive     = 1
            Saucer->evasive   = 0
            Saucer->newhead   = 0
            Saucer->size      = IIf(RNDBOOL,2,4)
            Saucer->sound     = IIf(Saucer->size=2,0,1)
            Saucer->poly.zoom = Saucer->size
            Saucer->speed     = 4         
            Saucer->poly.y    = Rnd*DSP_H
         End If
      End If
      
   End If
   
End Sub

Function IsSpawnAreaClear( SpawnBox As _polygon Ptr, Asteroids As _asteroid Ptr) As Integer

   For a As Integer = 0 To MAX_ROIDS-1
      If Asteroids[a].size Then
         If SpawnBox->TestCollision( Asteroids[a].poly ) Then
            Return 0
         End If
      End If
   Next 
   
   Return 1
   
End Function

Function AllAsteroidsDestroyed( Asteroids As _asteroid Ptr) As Integer

   For a As Integer = 0 To MAX_ROIDS-1
      If Asteroids[a].size Then
         Return 0
      End If
   Next 

   Return 1
     
End Function

Sub SaveHiScoreTable(HS() As _HSCR)
   
   If Open("hiscore.dat", For Binary, As #1)=0 Then
      Put #1,,HS()
      Close #1
   End If
   
End Sub

Sub LoadHiScoreTable(HS() As _HSCR)
   
   If FileExists("hiscore.dat") Then
      If Open("hiscore.dat", For Binary, As #1)=0 Then
         Get #1,,HS()
         Close #1
      End If
   Else
      'Build demo score table
      For s As Integer = 0 To 8
         HS(s).Player(0) = 65
         HS(s).Player(1) = 65
         HS(s).Player(2) = 65
         HS(s).Score = 15000-(s*1400)
         HS(s).Level = 9-s
      Next
      SaveHiScoreTable( HS() )
   End If
   
End Sub

Sub UpdateHiScore(HS() As _HSCR, Player As _player Ptr, pname As String)
   
   For s As Integer = 0 To 9
      If Player->score > HS(s).Score Then
         For m As Integer = 9 To s+1 Step -1
            HS(m)=HS(m-1)                        
         Next
         HS(s).Player(0) = pname[0]
         HS(s).Player(1) = pname[1]
         HS(s).Player(2) = pname[2]
         HS(s).Score     = Player->score
         HS(s).Level     = Player->level
         SaveHiScoreTable( HS() )
         Exit Sub
      End If
   Next
   
End Sub

Sub ClearKeyboardBuffer()
   While Len(InKey)
      Sleep 1,1
   Wend
End Sub
/'*********************************************
                  MAIN PROGRAM
*********************************************'/
Enum _GameStates
   Intro
   Init_Start
   Init_Level
   Game_Play
   Level_Trans
   Game_Over
   Hi_Score
   Get_HiScore
   Exit_Game
   Program_End
End Enum

Randomize
   
ScreenRes SCR_W,SCR_H,32
WindowTitle "Asteroids Clone by Vincent DeCampo (ver .991)"

Window Screen (0,0)-(DSP_W,DSP_H)

'Timers
Dim As Double tmrPROCESS,tmrPLAYER,tmrSHOTS

'Game Entities
Dim Player     As _player Ptr
Dim PlayerMark As _polygon Ptr
Dim Asteroids  As _asteroid Ptr 
Dim Shot       As _shot Ptr
Dim Thruster   As _polygon Ptr
Dim Particles  As _Particle Ptr
Dim SpawnBox   As _polygon Ptr
Dim Saucer     As _saucer Ptr
Dim SaucerShot As _shot Ptr

'Poly Renderer
Dim DrawIt   As _render_poly
Dim VFont    As _vfont Ptr

   VFont = Init_Vector_Font()

'Game State Vars
Dim As _GameStates GameState, PrevState
Dim As Double      StateTTL
Dim As _HSCR       HSCORE(9)
Dim As String      pname, kinp 'varible for player initials

/'
      Init Sound system
'/
Dim As Integer SoundInit  = InitSound()
Dim As Integer sndShot    = LoadSound("sounds\shot.wav")
Dim As Integer sndHeart   = LoadSound("sounds\heartbeat.wav")
Dim As Integer sndExplode = LoadSound("sounds\sexplode.wav")
Dim As Integer sndThrust  = LoadSound("sounds\thrust.wav")
Dim As Integer sndUFO(1)  
   
   sndUFO(0) = LoadSound("sounds\smallufo.wav")
   sndUFO(1) = LoadSound("sounds\bigufo.wav")

   fbs_Set_SoundSpeed(sndHeart, .8)
     
   /'
      Initialize Player 
   '/
   Player       = New _player
   PlayerMark   = New _polygon
   
   Player->poly.zoom = 2
   Player->poly.x=DSP_W2
   Player->poly.y=DSP_H2

   ReadVertices(Player1, Player->poly)'Image frame #1
      
   PlayerMark[0] = Player->poly
   PlayerMark[0].x = 30
   PlayerMark[0].y = 40
   PlayerMark[0].zoom = 2
   PlayerMark[0].rot = -PI/2
   
   Thruster = New _Polygon[2]
   
   ReadVertices(Player2, Thruster[0])  'Image frame #2
   ReadVertices(Player3, Thruster[1])  'Image frame #3

   /'
      Initialize Respawn Box
   '/
   SpawnBox = New _polygon
   SpawnBox->zoom = 40
   SpawnBox->x=DSP_W2
   SpawnBox->y=DSP_H2
      
   ReadVertices(RespawnBox, SpawnBox[0])
   
   /'
      Initialize Shots
   '/
   Shot = New _Shot[MAX_SHOTS]
      
   ReadVertices(Bullet, Shot[0].poly) 'Bullet #1
   ReadVertices(Bullet, Shot[1].poly) 'Bullet #2
   ReadVertices(Bullet, Shot[2].poly) 'Bullet #3
   ReadVertices(Bullet, Shot[3].poly) 'Bullet #4
      
   /'
      Initialize Asteroids
   '/
   Asteroids = New _asteroid[MAX_ROIDS]
   GenerateAsteroids(Asteroids, 2)   
   
   /'
      Initialize Saucer      
   '/
   Saucer = New _saucer
   
   ReadVertices(UFO, Saucer[0].poly)
   
   SaucerShot = New _Shot
   
   ReadVertices(Bullet, SaucerShot[0].poly) 'Bullet #1
   
   /'
      Initialize Particles
   '/
   Particles = New _Particle[MAX_PARTICLES] 
   
   /'
      Set Initial Game State      
   '/
   GameState = 0

   LoadHiScoreTable(HSCORE())

   Do 'Outer Game Loop

      /'
         Game State Machine
      '/
      Select Case GameState
         
         Case Intro   'Intro/Demo
            
            'Press F2 to Start
            If MultiKey(FB.SC_F2) Then GameState = Init_Start
            If Timer > StateTTL Then 
               GameState = Hi_Score
               StateTTL  = Timer+10
            End If
         
         Case Init_Start
   
            Player->poly.x=DSP_W2
            Player->poly.y=DSP_H2
            Player->xacc  = 0
            Player->yacc  = 0
            Player->score = 0
            Player->lives = 3
            Player->level = 1
            pname = ""
            GameState = Init_Level
            
         Case Init_Level
            
            GenerateAsteroids(Asteroids, Player->level)
            Player->alive = IIf(Player->lives > 0,1,0)
            Player->astcount = MAX_ROIDS
            GameState = Game_Play
                        
         Case Game_Play
            
            SustainSound(sndHeart)

         Case Level_Trans
            
            If Timer > StateTTL Then
               Player->level += 1
               GameState = Init_Level   
            End If
            
         Case Game_Over

            ClearKeyboardBuffer
            Player->thrust = 0
            If Player->score > HScore(9).score Then
               pname = ""
               GameState = Get_HiScore
            Else
               GameState = Hi_Score   
               StateTTL  = Timer+10          
            End If
            
         Case Hi_Score
         
            If MultiKey(FB.SC_F2) Then GameState = Init_Start
            If Timer > StateTTL Then
               GameState = Intro  
               StateTTL  = Timer + 20               
            End If
         
         Case Get_HiScore
            
            kinp = InKey
            If Len(kinp) Then
               If kinp[0] >= 65 And kinp[0] <= 122 Then
                  pname += UCase(kinp)                 
                  If Len(pname)=3 Then
                     UpdateHiScore(HScore(), Player, pname)
                     GameState = Hi_Score
                     StateTTL  = Timer + 10
                  End If
               End If
            End If
            
         Case Exit_Game
            
            If MultiKey(FB.SC_Y) Then GameState = Program_End
            If MultiKey(FB.SC_N) Then GameState = PrevState
         
         Case Program_End
            
            Exit Do
            
      End Select
      
      If GameState <> Exit_Game Then
         
         /'
            Process Sprite Movement
         '/
         If Timer-tmrPROCESS > GameTick Then
            Player->astcount = ProcessRoids( Asteroids )
            ProcessSaucer(Saucer, Player, SaucerShot, Player->astcount)
            tmrPROCESS = Timer
            If Saucer->alive Then
               SustainSound( sndUFO(Saucer->sound) )
            End If
         End If
         /'
            Process Player Movement         
         '/
         If GameState = Game_Play OrElse GameState = Level_Trans Then
            If Timer-tmrPLAYER > GameTick Then
               If ProcessPlayer(Player, Shot) Then
                  SoundEffect(sndShot,1)
               End If
               If Player->thrust Then
                  SustainSound(sndThrust)
               Else
                  fbs_Set_SoundPaused (sndThrust,1)
               End If            
               tmrPLAYER = Timer
            End If
         End If
   
         /'
            Process Shots at faster rate for collision accuracy
         '/
         If Timer-tmrSHOTS > ShotTick Then
            ProcessSaucerShots(SaucerShot)        
            ProcessShots(Shot)
            tmrSHOTS = Timer
         End If
         
         /'
            Check to exit game
         '/
         If MultiKey(FB.SC_ESCAPE) Then
            PrevState = GameState
            GameState = Exit_Game
         End If
      
      End If
      
      /'
      **************   Rendering **************
      '/
      ScreenLock
         
         'Clear Screen
         Cls
                  
         'Draw Asteroids                 
         For a As Integer = 0 To MAX_ROIDS-1
            If Asteroids[a].size Then
               DrawIt.RenderPoly(Asteroids[a].poly)
            End If
         Next        
         
         'Draw Player
         If Player->alive Then
            If Player->thrust Then
               SyncThrusterPositions(Player, Thruster)
               If Player->frame = 0 Then
                  Player->frame = 1
                  DrawIt.RenderPoly(Thruster[0]) 'Ship Image w/ Thruster #1
               Else
                  Player->frame = 0
                  DrawIt.RenderPoly(Thruster[1]) 'Ship Image w/ Thruster #2
               End If
            Else
               DrawIt.RenderPoly(Player->poly) 'Ship Image at rest
            End If
         End If
         
         'Draw Shots
         For a As Integer = 0 To MAX_SHOTS-1
            If Shot[a].ttl > Timer Then
               DrawIt.RenderPoly(Shot[a].poly)
            End If
         Next        

         If SaucerShot[0].ttl > Timer Then
            DrawIt.RenderPoly(SaucerShot[0].poly)
         End If
         
         'Draw Particles
         RenderParticles( Particles )
         
         'Draw UFO
         If Saucer->alive Then
            DrawIt.RenderPoly (Saucer->poly)
         End If
         
         VPrint(vfont,15,20, Format(Player->score,"0000"),.75)
         VPrint(vfont,DSP_W2,DSP_H-25,"(c)1979 ATARI INC", .5,VFONT_CENTER)
         
         Select Case GameState
            Case Intro, Game_Over
               VPrint(vfont,DSP_W2,150,"ASTEROIDS",3,VFONT_CENTER)
               VPrint(vfont,DSP_W2,DSP_H2-60,"Press F2 To Start",.5,VFONT_CENTER)
               VPrint(vfont,DSP_W2,DSP_H2-30,"GAME OVER",1,VFONT_CENTER)
               VPrint(vfont,DSP_W2,DSP_H2+130,"CONTROLS",.5,VFONT_CENTER)
               VPrint(vfont,DSP_W2,DSP_H2+150,"L/R/UP Arrows Move",.5,VFONT_CENTER)
               VPrint(vfont,DSP_W2,DSP_H2+170,"SPACE = Shoot",.5,VFONT_CENTER)
               VPrint(vfont,DSP_W2,DSP_H2+190,"CTRL = Hyperspace",.5,VFONT_CENTER)
               VPrint(vfont,DSP_W2,DSP_H2+230,"EXTRA LIFE EVERY " & EXTRA_LIFE &" POINTS",.5,VFONT_CENTER)
            Case Hi_Score
               VPrint(vfont,DSP_W2,100,"HIGH SCORES",1,VFONT_CENTER)
               For n As Integer = 0 To 9
                  VPrint(vfont,DSP_W2-100,150+(n*30),Str(n+1),1,VFONT_RIGHT)
                  VPrint(vfont,DSP_W2+40,150+(n*30),Str(HSCORE(n).Score),1,VFONT_RIGHT)
                  Dim tmp As String = "XXX" 
                  tmp[0] = HSCORE(n).Player(0)
                  tmp[1] = HSCORE(n).Player(1)
                  tmp[2] = HSCORE(n).Player(2)
                  VPrint(vfont,DSP_W2+60,150+(n*30),tmp,1,VFONT_LEFT)
               Next n
            Case Get_HiScore
               VPrint(vfont,DSP_W2,DSP_H2-200,"GREAT SCORE!",1,VFONT_CENTER )
               VPrint(vfont,DSP_W2,DSP_H2-150,"ENTER YOUR INITIALS",1,VFONT_CENTER )
               VPrint(vfont,DSP_W2,DSP_H2-50,pname,1,VFONT_CENTER )
            Case Exit_Game
               VPrint(vfont,DSP_W2,DSP_H2,"EXIT GAME(Y/N)?",1,VFONT_CENTER )
            Case Else
               VPrint(vfont,DSP_W2,15,Format(Player->level-1,"00"),.5 )
               For pm As Integer = 0 To Player->lives-1
                  PlayerMark[0].x = 30 + (15*pm)
                  DrawIt.RenderPoly(PlayerMark[0])
               Next
         End Select
         
      ScreenUnLock
      /'
      **************    End Rendering  **************      
      '/
      
      /'
      **************   Collision Detection   **************
      '/
      'Check Shots against roids
      For s As Integer = 0 To MAX_SHOTS-1
         If Shot[s].ttl > Timer Then
            For a As Integer = 0 To MAX_ROIDS-1
               If Asteroids[a].size Then
                  If Asteroids[a].poly.TestCollision( Shot[s].poly ) Then
                     'Process Shot->Asteroid collision
                     Player->score += 50-Asteroids[a].size*10
                     SpawnParticles(Particles, Shot[s].poly.x, Shot[s].poly.y,10,.05,Rnd)
                     Shot[s].ttl = 0
                     SoundEffect(sndExplode)
                     If ProcessCollisionWithAsteroid( Asteroids, a ) Then
                        GameState = Level_Trans
                        StateTTL  = Timer+3
                     End If
                  End If
               End If
            Next 
         End If
      Next 

      'Check Shots against UFO
      If Saucer->alive Then
         For s As Integer = 0 To MAX_SHOTS-1
            If Shot[s].ttl > Timer Then
               If Saucer->poly.TestCollision( Shot[s].poly ) Then
                  'Process Shot->UFO collision
                  Player->score += 50*Saucer->size
                  SpawnParticles(Particles, Shot[s].poly.x, Shot[s].poly.y,10,.05,Rnd)
                  Shot[s].ttl = 0
                  Saucer->alive = 0
                  SoundEffect(sndExplode)
               End If
            End If
         Next 
      End If
            
      'Check roids against player
      If Player->alive Then
         For a As Integer = 0 To MAX_ROIDS-1
            If Asteroids[a].size Then
               If Asteroids[a].poly.TestCollision( Player->poly ) Then
                  'Process Ship->Asteroid collision
                  ProcessShipCollision( Player )
                  SpawnParticles(Particles, Player->poly.x, Player->poly.y,10,.05,Rnd)
                  SoundEffect(sndExplode)
                  If ProcessCollisionWithAsteroid( Asteroids, a ) Then
                     GameState = Level_Trans
                     StateTTL  = Timer+3
                  End If                  
               End If
            End If
         Next 
      End If
           
      'Check roids against UFO
      If Saucer->alive Then
         For a As Integer = 0 To MAX_ROIDS-1
            If Asteroids[a].size Then
               If Asteroids[a].poly.TestCollision( Saucer->poly ) Then
                  'Process UFO->Asteroid collision
                  Saucer->alive = 0
                  SpawnParticles(Particles, Saucer->poly.x, Saucer->poly.y,10,.05,Rnd)
                  SoundEffect(sndExplode)
                  If ProcessCollisionWithAsteroid( Asteroids, a ) Then
                     GameState = Level_Trans
                     StateTTL  = Timer+3
                  End If                  
               End If
            End If
         Next 
      End If
      
      'Check UFO against player
      If Player->alive AndAlso Saucer->alive Then
         If Player->poly.TestCollision( Saucer->poly ) Then
            'Process UFO->Ship
            Saucer->alive = 0            
            ProcessShipCollision( Player )
            SpawnParticles(Particles, Player->poly.x, Player->poly.y,10,.05,Rnd)
            SoundEffect(sndExplode)
         End If
      End If

      'Check UFO Shot against player
      If Saucershot->ttl > Timer AndAlso Player->alive Then
         If Player->poly.TestCollision( SaucerShot->poly ) Then
            'Process UFO Shot->Ship
            Saucershot->ttl = 0
            ProcessShipCollision( Player )
            SpawnParticles(Particles, Player->poly.x, Player->poly.y,10,.05,Rnd)
            SoundEffect(sndExplode)
         End If
      End If

      /'
      ************** End Collision Detection **************      
      '/

      'Player Killed?
      If (Player->alive = 0 OrElse GameState = 0) Then
         If GameState <> Get_HiScore Then
            If (Player->lives < 1 AndAlso GameState = Game_Play ) Then
               GameState = Game_Over            
            Else
               If Timer > Player->respawn Then
                  If IsSpawnAreaClear(SpawnBox, Asteroids) Then
                     Player->alive  = 1
                     Player->xacc   = 0
                     Player->yacc   = 0
                     Player->poly.x = DSP_W2
                     Player->poly.y = DSP_H2
                  End If
               End If
            End If
         End If
      End If

      'Check to award extra life
      If GameState = Game_Play Then
         If Player->score > Player->NextLife Then
            Player->NextLife += EXTRA_LIFE
            Player->lives    +=1
         EndIf
      EndIf
      
      Sleep 1,1
     
     
   Loop
  
   fbs_Set_SoundPaused (sndThrust,0)
  
/'
   Object Cleanup
'/
   Delete[] Thruster
   Delete   SpawnBox 
   Delete[] Shot
   Delete[] Particles
   Delete[] Asteroids
   Delete   Saucer
   Delete   SaucerShot
   Delete   PlayerMark
   Delete   Player
   
/'
   Vertex Data
'/
Ast1:
Data 0,0,3,0,4,1,4,2,5,2,6,3,6,4,4,7,2,7,2,6,1,5,0,5,0,3,1,2,0,1,0,0,255,255

Player1:
Data 0,0,8,3,0,6,2,3,0,0,255,255

Player2:
Data 0,0,8,3,0,6,2,3,1,2,0,3,1,4,2,3,0,0,255,255

Player3:
Data 0,0,8,3,0,6,2,3,1,2,-4,3,1,4,2,3,0,0,255,255

Bullet:
Data 0,0,1,0,1,1,0,1,0,0,255,255

UFO:
Data 8,3,6,2,2,2,3,1,5,1,8,3,6,2,2,2,0,3,1,4,7,4,8,3,255,255

RespawnBox:
Data 0,0,4,0,4,3,0,3,0,0,255,255

